@@ -182,6 +182,27 @@ class Account(Entity):
                 for data in result
             ]
 
+    def get_zone(self, zone_id, params=None, raw=False, api_call_kwargs={}, **kwargs):
+        """:obj:`Zone`: Fetch the zone with specified id in the account.
+
+        Args:
+            zone_id
+            params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
+            **kwargs (dict): Extra attributes for Zone objects.
+        """
+        result = self.api.call(
+            "GET",
+            "/accounts/{}/zones/{}".format(self._id, zone_id),
+            params=params,
+            **api_call_kwargs,
+        )
+        if raw:
+            return result
+        else:
+            return Zone(result['id'], result, api=self.api, **kwargs)
+
     def get_alert(self, alert_id, attributes=None, raw=False, params=None, api_call_kwargs={}):
         """:obj:`Alert`: Fetch an Alert by its ID
 
