@@ -2,6 +2,9 @@ import click
 
 from freedomrobotics_api import __version__
 from freedomrobotics_api.cli.commands.setup import setup
+from freedomrobotics_api.cli.commands.device import (
+    device,
+)
 
 
 @click.group()
@@ -11,6 +14,7 @@ def cli(args=None):
 
 
 cli.add_command(setup)
+cli.add_command(device)
 
 if __name__ == '__main__':
     cli()
